@@ -46,7 +46,7 @@ OC.L10N.register(
     "after end" : "lopun jälkeen",
     "Comment" : "Kommentti",
     "Add a comment" : "Lisää kommentti",
-    "This will delete the Calendar \"%s\" and all of its entries." : "Tämä poistaa kalenterin \"%s\" ja kaikki sen merkinnät.",
+    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Tämä poistaa kalenterin \"%s\" ja kaikki sitä vastaavat tapahtumat sekä tehtävät.",
     "The name \"%s\" is already used." : "Nimi \"%s\" on jo käytössä.",
     "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
     "Hidden" : "Piilotettu",
