@@ -46,7 +46,7 @@ OC.L10N.register(
     "after end" : "po ukončení",
     "Comment" : "Komentár",
     "Add a comment" : "Pridať komentár",
-    "This will delete the Calendar \"%s\" and all of its entries." : "Táto operácia odstráni kalendár \"%s\" a všetky jeho položky.",
+    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Táto operácia odstráni kalendár \"%s\" a všetky jeho udalosti a úlohy.",
     "The name \"%s\" is already used." : "Názov \"%s\" je už použitý.",
     "An empty name is not allowed." : "Prázdny názov nie je povolený",
     "Hidden" : "Skryté",
@@ -85,6 +85,7 @@ OC.L10N.register(
     "All" : "Všetky",
     "Current" : "Aktuálne",
     "Completed" : "Dokončené",
+    "The Tasks app for Nextcloud" : "Aplikácia úloh pre Nextcloud",
     "Delete" : "Zmazať",
     "Cancel" : "Zrušiť",
     "Edit" : "Upraviť",
